@@ -30,6 +30,7 @@ class DocumentMetadataFields(BaseModel):
     publication_date: Optional[int]
     publication_author: Optional[str]
     description: Optional[str]
+    language: Optional[str]
     parent_uuid: Optional[str]
     url: Optional[str]
     platform: Optional[str]
@@ -41,6 +42,7 @@ class DocumentMetadataFields(BaseModel):
     markers: Optional[Tuple[str, ...]]
     related_concept_id: Optional[str]
     preview_text: Optional[str]
+    story: Optional[str]
 
     class Config:
         extra = 'allow'  # any other extra fields will be kept
